@@ -68,7 +68,7 @@ class _PackagerRelations:
         return self.get_nodes(incoming=False, outgoing=True)
 
     def get_ordered_packagers(self):
-        """ Get a list of ordered names from the dependency chain.
+        """ Get a list of ordered packagers from the dependency chain.
 
             :param generalpackager.Packager self: """
         return [packager for packager_set in self.get_ordered() for packager in sorted(packager_set, key=lambda x: x.name)]
